powered by
Validates an iblm model object has required structure and features
check_iblm_model(model, booster_models_supported = c("xgb.Booster"))
Invisible TRUE if all checks pass
Model object to validate, expected class "iblm"
Booster model classes currently supported in the iblm package
df_list <- freMTPLmini |> split_into_train_validate_test(seed = 9000) iblm_model <- train_iblm_xgb( df_list, response_var = "ClaimRate", family = "poisson" ) check_iblm_model(iblm_model)
Run the code above in your browser using DataLab